.. _index:

StreamSets Platform SDK for Python
==================================
|

The StreamSets Platform SDK for Python enables users to interact with StreamSets Platform programmatically using Python 3.4+.

Documentation For Earlier Versions
----------------------------------

* Platform SDK
    * `SDK 5.x documentation <https://docs.streamsets.com/platform-sdk/5.x/index.html>`_
    * `SDK 4.x documentation <https://docs.streamsets.com/platform-sdk/4.x/index.html>`_

* Legacy SDK
    * `SDK 3.x documentation <https://docs.streamsets.com/sdk/latest/index.html>`_

.. toctree::
    :maxdepth: 3
    :hidden:

    welcome
    set_up
    build
    run
    monitor
    manage
    advanced_search
    api
